==> yappari_0.0.29.tar.gz: yappari-0.0.29/src/yappari-application/Gui/chatimageitem.h <==
/* Copyright 2012 Naikel Aparicio. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL EELI REILIN OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Eeli Reilin.
 */

#ifndef CHATIMAGEITEM_H
#define CHATIMAGEITEM_H

#include <QWidget>

#include "Whatsapp/fmessage.h"

namespace Ui {
    class ChatImageItem;
}

class ChatImageItem : public QWidget
{
    Q_OBJECT

public:
    explicit ChatImageItem(FMessage message, QWidget *parent = 0);
    ~ChatImageItem();

public slots:
    void viewImageInBrowser();
    void setNickname(FMessage message);
    void setTimestamp(FMessage message);
    void updateTimestamp();

private:
    Ui::ChatImageItem *ui;

    FMessage message;
};

#endif // CHATIMAGEITEM_H

==> yappari_0.0.34.tar.gz: yappari-0.0.34/src/yappari-application/Gui/chatimageitem.h <==
/* Copyright 2012 Naikel Aparicio. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL EELI REILIN OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Eeli Reilin.
 */

#ifndef CHATIMAGEITEM_H
#define CHATIMAGEITEM_H

#include <QWidget>

#include "Whatsapp/fmessage.h"

namespace Ui {
    class ChatImageItem;
}

class ChatImageItem : public QWidget
{
    Q_OBJECT

public:
    explicit ChatImageItem(FMessage message, QWidget *parent = 0);

    ~ChatImageItem();

signals:
    void mediaDownload(FMessage message);

public slots:
    void downloadOrViewImage();
    void setImage();
    void setNickname(FMessage message);
    void setTimestamp(FMessage message);
    void setButton();
    void updateTimestamp();
    void updateProgress(float p);
    void updateUri(QString uri);
    void updateImage(FMessage message);
    void resetButton();

private:
    Ui::ChatImageItem *ui;
    bool waiting;

    FMessage message;
};

#endif // CHATIMAGEITEM_H
